@@ -1,9 +1,12 @@
 package Setup::File::Symlink;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.27'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use File::Trash::Undoable;
 
@@ -11,10 +14,13 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(setup_symlink);
 
-our $VERSION = '0.26'; # VERSION
-
 our %SPEC;
 
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'Setup symlink (existence, target)',
+};
+
 $SPEC{rmsym} = {
     v           => 1.1,
     summary     => 'Delete symlink',
@@ -348,18 +354,26 @@ Setup::File::Symlink - Setup symlink (existence, target)
 
 =head1 VERSION
 
-This document describes version 0.26 of Setup::File::Symlink (from Perl distribution Setup-File-Symlink), released on 2014-05-17.
+This document describes version 0.27 of Setup::File::Symlink (from Perl distribution Setup-File-Symlink), released on 2015-08-18.
+
+=head1 SEE ALSO
+
+L<Setup>
+
+L<Setup::File>
 
 =head1 FUNCTIONS
 
 
 =head2 ln_s(%args) -> [status, msg, result, meta]
 
-Create symlink.
+{en_US Create symlink}.
 
+{en_US 
 Fixed state: C<symlink> exists and points to C<target>.
 
 Fixable state: C<symlink> doesn't exist.
+}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -370,11 +384,11 @@ Arguments ('*' denotes required arguments):
 
 =item * B<symlink> => I<str>
 
-Path to symlink.
+{en_US Path to symlink}.
 
 =item * B<target> => I<str>
 
-Path to target.
+{en_US Path to target}.
 
 =back
 
@@ -404,8 +418,6 @@ For more information on transaction, see L<Rinci::Transaction>.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -415,17 +427,21 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
+Return value:  (any)
+
 
 =head2 rmsym(%args) -> [status, msg, result, meta]
 
-Delete symlink.
+{en_US Delete symlink}.
 
+{en_US 
 Will not delete non-symlinks.
 
 Fixed state: C<path> doesn't exist.
 
 Fixable state: C<path> exists, is a symlink, (and if C<target> is defined, points
 to C<target>).
+}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -438,7 +454,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<target> => I<str>
 
-Only delete if existing symlink has this target.
+{en_US Only delete if existing symlink has this target}.
 
 =back
 
@@ -468,8 +484,6 @@ For more information on transaction, see L<Rinci::Transaction>.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -479,12 +493,15 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
+Return value:  (any)
+
 
 =head2 setup_symlink(%args) -> [status, msg, result, meta]
 
-Setup symlink (existence, target).
+{en_US Setup symlink (existence, target)}.
 
-When C<should_exist=>1> (the default): On do, will create symlink which points to
+{en_US 
+When C<< should_exist=E<gt>1 >> (the default): On do, will create symlink which points to
 specified target. If symlink already exists but points to another target, it
 will be replaced with the correct symlink if C<replace_symlink> option is true.
 If a file/dir already exists and C<replace_file>/C<replace_dir> option is true, it
@@ -492,9 +509,10 @@ will be moved (trashed) first before the symlink is created. On undo, will
 delete symlink if it was created by this function, and restore the original
 symlink/file/dir if it was replaced during do.
 
-When C<should_exist=>0>: On do, will remove symlink if it exists (and
+When C<< should_exist=E<gt>0 >>: On do, will remove symlink if it exists (and
 C<replace_symlink> is true). If C<replace_file>/C<replace_dir> is true, will also
 remove file/dir. On undo, will restore deleted symlink/file/dir.
+}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -505,41 +523,51 @@ Arguments ('*' denotes required arguments):
 
 =item * B<create> => I<bool> (default: 1)
 
-Create if symlink doesn't exist.
+{en_US Create if symlink doesn't exist}.
 
+{en_US 
 If set to false, then setup will fail (412) if this condition is encountered.
+}
 
 =item * B<replace_dir> => I<bool> (default: 0)
 
-Replace if there is existing dir.
+{en_US Replace if there is existing dir}.
 
+{en_US 
 If set to false, then setup will fail (412) if this condition is encountered.
+}
 
 =item * B<replace_file> => I<bool> (default: 0)
 
-Replace if there is existing non-symlink file.
+{en_US Replace if there is existing non-symlink file}.
 
+{en_US 
 If set to false, then setup will fail (412) if this condition is encountered.
+}
 
 =item * B<replace_symlink> => I<bool> (default: 1)
 
-Replace previous symlink if it already exists but doesn't point to the wanted target.
+{en_US Replace previous symlink if it already exists but doesn't point to the wanted target}.
 
+{en_US 
 If set to false, then setup will fail (412) if this condition is encountered.
+}
 
 =item * B<should_exist> => I<bool> (default: 1)
 
-Whether symlink should exist.
+{en_US Whether symlink should exist}.
 
 =item * B<symlink>* => I<str>
 
-Path to symlink.
+{en_US Path to symlink}.
 
 =item * B<target> => I<str>
 
-Target path of symlink.
+{en_US Target path of symlink}.
 
-Required, unless C<should_exist => 0>.
+{en_US 
+Required, unless C<< should_exist =E<gt> 0 >>.
+}
 
 =back
 
@@ -569,8 +597,6 @@ For more information on transaction, see L<Rinci::Transaction>.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -580,11 +606,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-=head1 SEE ALSO
-
-L<Setup>
-
-L<Setup::File>
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -592,7 +614,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Setup-File
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Setup-File-Symlink>.
+Source repository is at L<https://github.com/perlancar/perl-Setup-File-Symlink>.
 
 =head1 BUGS
 
@@ -604,11 +626,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
